@@ -21,7 +21,6 @@
 
 
 import os
-import traceback
 from gettext import gettext as _
 
 from gi.repository import Gst, GLib, Gio
@@ -54,6 +53,8 @@ def find_available_elements():
     # some functions can be provided by various packages.
     # move preferred packages towards the bottom.
     encoders = [
+        ('asfmux', 'WMA', 'wma-enc', BAD),
+        ('avenc_wmav2', 'WMA', 'wma-enc', LIBAV),
         ('flacenc', 'FLAC', 'flac-enc', GOOD),
         ('wavenc', 'WAV', 'wav-enc', GOOD),
         ('vorbisenc', 'Ogg Vorbis', 'vorbis-enc', BASE),
@@ -98,6 +99,8 @@ def find_available_elements():
     if 'mp4mux' not in available_elements:
         available_elements.discard('faac')
         available_elements.discard('avenc_aac')
+    if 'asfmux' not in available_elements:
+        available_elements.discard('avenc_wmav2')
 
 
 find_available_elements()
@@ -200,6 +203,12 @@ def create_opus_encoder():
         'bandwidth=auto ! oggmux'
     ).format(opus_quality * 1000)
 
+def create_wma_encoder():
+    """Return an wma encoder for the gst pipeline string."""
+    wma_quality = get_gio_settings().get_int('wma-bitrate')
+    return (
+        'avenc_wmav2 bitrate={} ! asfmux'
+    ).format(wma_quality * 1000)
 
 class Converter(Task):
     """Completely handle the conversion of a single file."""
@@ -222,7 +231,6 @@ class Converter(Task):
         self.newname = None
         self.existing_behaviour = Converter.INCREMENT
         self.name_generator = name_generator
-        self.callback = lambda: None
 
         # All relevant gio settings have to be copied and remembered, so that
         # they don't suddenly change during the conversion
@@ -237,10 +245,12 @@ class Converter(Task):
         # State
         self.command = None
         self.pipeline = None
-        self.done = False
+        self._done = False
         self.error = None
         self.output_uri = None
 
+        super().__init__()
+
     def _query_position(self):
         """Ask for the stream position of the current pipeline."""
         if self.pipeline:
@@ -254,21 +264,21 @@ class Converter(Task):
         """Fraction of how much of the task is completed."""
         duration = self.sound_file.duration
 
-        if self.done:
+        if self._done:
             return 1, duration
 
         if self.pipeline is None or duration is None:
             return 0, duration
 
         position = self._query_position()
-        progress = position / duration
+        progress = position / duration if duration else 0
         progress = min(max(progress, 0.0), 1.0)
         return progress, duration
 
     def cancel(self):
         """Cancel execution of the task."""
         self._stop_pipeline()
-        self.callback()
+        self.done()
 
     def pause(self):
         """Pause execution of the task."""
@@ -288,7 +298,7 @@ class Converter(Task):
         """Delete the pipeline."""
         if self.pipeline is not None:
             bus = self.pipeline.get_bus()
-            if hasattr(bus, 'watch_id'):
+            if hasattr(self, 'watch_id'):
                 bus.disconnect(self.watch_id)
                 bus.remove_signal_watch()
             self.pipeline.set_state(Gst.State.NULL)
@@ -353,14 +363,14 @@ class Converter(Task):
                 beautify_uri(input_uri),
                 self.error
             ))
-            self.callback()
+            self.done()
             return
 
         if not vfs_exists(self.temporary_filename):
             self.error = 'Expected {} to exist after conversion.'.format(
                 self.temporary_filename
             )
-            self.callback()
+            self.done()
             return
 
         # rename temporary file
@@ -394,12 +404,12 @@ class Converter(Task):
             vfs_rename(self.temporary_filename, newname)
         except Exception as error:
             self.error = str(error)
-            logger.error("could not rename '{}' to '{}':".format(
+            logger.error("could not rename '{}' to '{}': {}".format(
                 beautify_uri(self.temporary_filename),
                 beautify_uri(newname),
                 str(error)
             ))
-            self.callback()
+            self.done()
             return
 
         assert vfs_exists(newname)
@@ -413,8 +423,15 @@ class Converter(Task):
             # Copy file permissions
             source = Gio.file_parse_name(self.sound_file.uri)
             destination = Gio.file_parse_name(newname)
-            source.copy_attributes(destination, Gio.FileCopyFlags.NONE)
-
+            source.copy_attributes(destination, Gio.FileCopyFlags.ALL_METADATA)
+        except Exception as error:
+            logger.error(
+                "Could not set some attributes of the target '{}': {}".format(
+                    beautify_uri(newname),
+                    str(error)
+                )
+            )
+        try:
             # the modification date of the destination should be now
             info = Gio.FileInfo()
             now = GLib.DateTime.new_now(GLib.TimeZone())
@@ -432,7 +449,7 @@ class Converter(Task):
             )
         except Exception as error:
             logger.error(
-                "Could not set some attributes of the target '{}': {}".format(
+                "Could not set modification time of the target '{}': {}".format(
                     beautify_uri(newname),
                     str(error)
                 )
@@ -449,9 +466,12 @@ class Converter(Task):
                 ))
 
         self.output_uri = newname
-        self.done = True
-        self.callback()
+        self.done()
+
+    def done(self):
+        self._done = True
         self._cleanup()
+        super().done()
 
     def run(self):
         """Call this in order to run the whole Converter task."""
@@ -470,7 +490,7 @@ class Converter(Task):
             logger.info('output file already exists, skipping \'{}\''.format(
                 beautify_uri(self.newname)
             ))
-            self._conversion_done()
+            self.done()
             return
 
         # construct a pipeline for conversion
@@ -494,7 +514,8 @@ class Converter(Task):
             'audio/x-wav': create_wav_encoder,
             'audio/mpeg': create_mp3_encoder,
             'audio/x-m4a': create_aac_encoder,
-            'audio/ogg; codecs=opus': create_opus_encoder
+            'audio/ogg; codecs=opus': create_opus_encoder,
+            'audio/x-ms-wma': create_wma_encoder
         }[self.output_mime_type]()
         command.append(encoder)
 
@@ -531,7 +552,7 @@ class Converter(Task):
             beautify_uri(self.sound_file.uri)
         )
         self._stop_pipeline()
-        self.callback()
+        self.done()
 
     def _on_message(self, _, message):
         """Handle message events sent by gstreamer.
